@@ -15,7 +15,7 @@ class Fpm:
     self.forceBuild = ['--force'] if config.force_build else []
     self.packagePrefix = "o2-"
     self.targetDir = config.target_rpm_dir
-    self.skipDeps = ['openmp', 'VecGeom', 'O2-customization', 're2']  # as sometimes there's mismatch between "requires" deps and modulefile
+    self.skipDeps = ['openmp', 'VecGeom', 'O2-customization']  # as sometimes there's mismatch between "requires" deps and modulefile
 
     # Create output dir
     if not os.path.exists(self.targetDir):
